@@ -90,13 +90,8 @@ static PanelLayoutKeyDefinition panel_layout_toplevel_keys[] = {
         { PANEL_TOPLEVEL_MONITOR_KEY,         G_TYPE_INT      },
         { PANEL_TOPLEVEL_EXPAND_KEY,          G_TYPE_BOOLEAN  },
         { PANEL_TOPLEVEL_ORIENTATION_KEY,     G_TYPE_STRING   },
+        { PANEL_TOPLEVEL_ALIGNMENT_KEY,       G_TYPE_INT      },
         { PANEL_TOPLEVEL_SIZE_KEY,            G_TYPE_INT      },
-        { PANEL_TOPLEVEL_X_KEY,               G_TYPE_INT      },
-        { PANEL_TOPLEVEL_Y_KEY,               G_TYPE_INT      },
-        { PANEL_TOPLEVEL_X_RIGHT_KEY,         G_TYPE_INT      },
-        { PANEL_TOPLEVEL_Y_BOTTOM_KEY,        G_TYPE_INT      },
-        { PANEL_TOPLEVEL_X_CENTERED_KEY,      G_TYPE_BOOLEAN  },
-        { PANEL_TOPLEVEL_Y_CENTERED_KEY,      G_TYPE_BOOLEAN  },
         { PANEL_TOPLEVEL_AUTO_HIDE_KEY,       G_TYPE_BOOLEAN  },
         { PANEL_TOPLEVEL_ENABLE_BUTTONS_KEY,  G_TYPE_BOOLEAN  },
         { PANEL_TOPLEVEL_ENABLE_ARROWS_KEY,   G_TYPE_BOOLEAN  },
