@@ -25,6 +25,7 @@
 #define __PANEL_LOCKDOWN_H__
 
 #include <gio/gio.h>
+#include "libgnome-panel/gp-lockdown.h"
 
 G_BEGIN_DECLS
 
@@ -54,10 +55,6 @@ GType panel_lockdown_get_type (void);
 
 gboolean panel_lockdown_get_panels_locked_down   (PanelLockdown *lockdown);
 gboolean panel_lockdown_get_disable_command_line (PanelLockdown *lockdown);
-gboolean panel_lockdown_get_disable_lock_screen  (PanelLockdown *lockdown);
-gboolean panel_lockdown_get_disable_log_out      (PanelLockdown *lockdown);
-gboolean panel_lockdown_get_disable_switch_user  (PanelLockdown *lockdown);
-gboolean panel_lockdown_get_disable_force_quit   (PanelLockdown *lockdown);
 
 gboolean panel_lockdown_is_applet_disabled       (PanelLockdown *lockdown,
                                                   const char *iid);
@@ -74,12 +71,12 @@ void     panel_lockdown_on_notify                (PanelLockdown *      lockdown,
 PanelLockdown *panel_lockdown_get (void);
 
 gboolean panel_lockdown_get_panels_locked_down_s     (void);
-gboolean panel_lockdown_get_not_panels_locked_down_s (void);
 gboolean panel_lockdown_get_disable_command_line_s   (void);
-gboolean panel_lockdown_get_disable_lock_screen_s    (void);
-gboolean panel_lockdown_get_disable_log_out_s        (void);
-gboolean panel_lockdown_get_disable_switch_user_s    (void);
-gboolean panel_lockdown_get_disable_force_quit_s     (void);
+
+GpLockdownFlags panel_lockdown_get_flags   (PanelLockdown *lockdown,
+                                            const char    *iid);
+
+GpLockdownFlags panel_lockdown_get_flags_s (const char    *iid);
 
 G_END_DECLS
 
