@@ -314,7 +314,8 @@ set_environment (gpointer user_data)
 
   display = gdk_display_get_default ();
 
-  g_setenv ("DISPLAY", gdk_display_get_name (display), TRUE);
+  if (!g_setenv ("DISPLAY", gdk_display_get_name (display), TRUE))
+    g_warning ("Failed to set DISPLAY environment variable");
 }
 
 static void
@@ -522,7 +523,7 @@ panel_run_dialog_execute (PanelRunDialog *dialog)
 	error = NULL;
 	disk = g_locale_from_utf8 (command, -1, NULL, NULL, &error);
 
-	if (!disk || error) {
+	if (error != NULL) {
 		char *primary;
 
 		primary = g_strdup_printf (_("Could not convert '%s' from UTF-8"),
@@ -533,6 +534,8 @@ panel_run_dialog_execute (PanelRunDialog *dialog)
 		g_free (primary);
 
 		g_error_free (error);
+		g_free (command);
+		g_free (disk);
 		return;
 	}
 
