@@ -866,3 +866,18 @@ panel_util_key_event_is_popup_panel (GdkEventKey *event,
 	panel_util_key_event_is_binding (event, PANEL_TYPE_TOPLEVEL, "popup-panel-menu",
 					 is_popup, is_popup_modifier);
 }
+
+int
+panel_util_get_window_scaling_factor (void)
+{
+	GValue value = G_VALUE_INIT;
+
+	g_value_init (&value, G_TYPE_INT);
+
+	if (gdk_screen_get_setting (gdk_screen_get_default (),
+	                            "gdk-window-scaling-factor",
+	                            &value))
+		return g_value_get_int (&value);
+
+	return 1;
+}
