@@ -251,28 +251,6 @@ remove_all_move_bindings (PanelWidget *panel)
 	gtk_binding_entry_remove (binding_set, GDK_KEY_space, 0);
 }
 
-static void
-get_preferred_size_from_hints (AppletData *ad,
-                               int        *minimum_size,
-                               int        *natural_size)
-{
-  int max_size;
-  int min_size;
-  int i;
-
-  max_size = 0;
-  min_size = INT_MAX;
-
-  for (i = 0; i < ad->size_hints_len; i += 2)
-    {
-      max_size = MAX (max_size, ad->size_hints[i]);
-      min_size = MIN (min_size, ad->size_hints[i + 1]);
-    }
-
-  *minimum_size = min_size;
-  *natural_size = max_size;
-}
-
 static GtkSizeRequestMode
 panel_widget_get_request_mode (GtkWidget *widget)
 {
@@ -323,13 +301,6 @@ panel_widget_get_preferred_height (GtkWidget *widget,
 
           if (ad->expand_major)
             {
-              if (ad->size_hints != NULL)
-                {
-                  get_preferred_size_from_hints (ad,
-                                                 &child_min_height,
-                                                 &child_nat_height);
-                }
-
               min_height += child_min_height;
               nat_height += child_nat_height;
             }
@@ -388,13 +359,6 @@ panel_widget_get_preferred_width_for_height (GtkWidget *widget,
 
           if (ad->expand_major)
             {
-              if (ad->size_hints != NULL)
-                {
-                  get_preferred_size_from_hints (ad,
-                                                 &child_min_width,
-                                                 &child_nat_width);
-                }
-
               min_width += child_min_width;
               nat_width += child_nat_width;
             }
@@ -451,13 +415,6 @@ panel_widget_get_preferred_width (GtkWidget *widget,
 
           if (ad->expand_major)
             {
-              if (ad->size_hints != NULL)
-                {
-                  get_preferred_size_from_hints (ad,
-                                                 &child_min_width,
-                                                 &child_nat_width);
-                }
-
               min_width += child_min_width;
               nat_width += child_nat_width;
             }
@@ -516,13 +473,6 @@ panel_widget_get_preferred_height_for_width (GtkWidget *widget,
 
           if (ad->expand_major)
             {
-              if (ad->size_hints != NULL)
-                {
-                  get_preferred_size_from_hints (ad,
-                                                 &child_min_height,
-                                                 &child_nat_height);
-                }
-
               min_height += child_min_height;
               nat_height += child_nat_height;
             }
@@ -962,6 +912,39 @@ panel_widget_update_positions (PanelWidget *panel)
 
 			i = ad->position + ad->size;
 		}
+
+		/* Third pass: try to push applets to the left to see if
+		 * there is enough room. */
+		if (i > panel->size) {
+			i = panel->size;
+			for (list = g_list_last (panel->applet_list);
+			     list != NULL;
+			     list = g_list_previous (list)) {
+				ad = list->data;
+
+				if (ad->position + ad->size > i)
+					ad->position = MAX (i - ad->size, 0);
+
+				i = ad->position;
+			}
+		}
+
+		/* EEEEK, there's not enough room, so shift applets even
+		 * at the expense of perhaps running out of room on the
+		 * right if there is no free space in the middle */
+		if (i < 0) {
+			i = 0;
+			for (list = panel->applet_list;
+			     list != NULL;
+			     list = g_list_next (list)) {
+				ad = list->data;
+
+				if (ad->position < i)
+					ad->position = i;
+
+				i = ad->position + ad->size;
+			}
+		}
 	}
 }
 
@@ -1460,19 +1443,8 @@ get_preferred_size (PanelWidget    *self,
                                                  &minimum_size->width,
                                                  &natural_size->width);
 
-      if (ad->expand_major)
-        {
-          if (ad->size_hints != NULL)
-            {
-              get_preferred_size_from_hints (ad,
-                                             &minimum_size->width,
-                                             &natural_size->width);
-            }
-        }
-      else
-        {
-          natural_size->width = minimum_size->width;
-        }
+      if (!ad->expand_major)
+        natural_size->width = minimum_size->width;
     }
   else if (self->orient == GTK_ORIENTATION_VERTICAL)
     {
@@ -1493,19 +1465,8 @@ get_preferred_size (PanelWidget    *self,
                                                  &minimum_size->height,
                                                  &natural_size->height);
 
-      if (ad->expand_major)
-        {
-          if (ad->size_hints != NULL)
-            {
-              get_preferred_size_from_hints (ad,
-                                             &minimum_size->height,
-                                             &natural_size->height);
-            }
-        }
-      else
-        {
-          natural_size->height = minimum_size->height;
-        }
+      if (!ad->expand_major)
+        natural_size->height = minimum_size->height;
     }
   else
     {
@@ -2284,8 +2245,6 @@ panel_widget_applet_destroy (GtkWidget *applet, gpointer data)
 		panel->applet_list = g_list_remove (panel->applet_list,ad);
 	}
 
-	g_free (ad->size_hints);
-
 	g_free (ad);
 }
 
@@ -2414,7 +2373,7 @@ panel_widget_add (PanelWidget         *panel,
 		ad->position = 0;
 		ad->expand_major = FALSE;
 		ad->expand_minor = FALSE;
-		ad->size_hints = NULL;
+
 		g_object_set_data (G_OBJECT (applet),
 				   PANEL_APPLET_DATA, ad);
 		
@@ -2710,31 +2669,6 @@ panel_widget_set_applet_expandable (PanelWidget *panel,
 	gtk_widget_queue_resize (GTK_WIDGET (panel));
 }
 
-void
-panel_widget_set_applet_size_hints (PanelWidget *panel,
-				    GtkWidget   *applet,
-				    int         *size_hints,
-				    int          size_hints_len)
-{
-	AppletData *ad;
-
-	ad = g_object_get_data (G_OBJECT (applet), PANEL_APPLET_DATA);
-	if (!ad)
-		return;
-
-	g_free (ad->size_hints);
-
-	if (size_hints_len > 0 && (size_hints_len % 2 == 0)) {
-		ad->size_hints     = size_hints;
-		ad->size_hints_len = size_hints_len;
-	} else {
-		g_free (size_hints);
-		ad->size_hints = NULL;
-	}
-
-	gtk_widget_queue_resize (GTK_WIDGET (panel));
-}
-
 gboolean
 panel_applet_is_in_drag (void)
 {
