@@ -41,7 +41,6 @@ typedef struct _PanelData PanelData;
 struct _PanelData {
 	GtkWidget *panel;
 	GtkWidget *menu;
-	guint deactivate_idle;
 };
 
 enum {
@@ -97,22 +96,10 @@ panel_applet_added(GtkWidget *widget, GtkWidget *applet, gpointer data)
 	orientation_change(info,PANEL_WIDGET(widget));
 }
 
-static gboolean
-deactivate_idle (gpointer data)
-{
-	PanelData *pd = data;
-	pd->deactivate_idle = 0;
-
-	return FALSE;
-}
-
 static void
 context_menu_deactivate (GtkWidget *w,
 			 PanelData *pd)
 {
-	if (pd->deactivate_idle == 0)
-		pd->deactivate_idle = g_idle_add (deactivate_idle, pd);
-
 	panel_toplevel_pop_autohide_disabler (PANEL_TOPLEVEL (pd->panel));
 }
 
@@ -137,10 +124,6 @@ panel_destroy (PanelToplevel *toplevel,
 
 	pd->panel = NULL;
 
-	if (pd->deactivate_idle != 0)
-		g_source_remove (pd->deactivate_idle);
-	pd->deactivate_idle = 0;
-
 	g_object_set_data (G_OBJECT (toplevel), "PanelData", NULL);
 	g_free (pd);
 }
@@ -311,7 +294,7 @@ set_background_image_from_uri (PanelToplevel *toplevel,
 		return FALSE;
 	}
 
-	g_settings_set_enum (settings, "custom-bg-image", TRUE);
+	g_settings_set_boolean (settings, "custom-bg-image", TRUE);
 	g_settings_set_string (settings, "bg-image", uri);
 
 	g_object_unref (settings);
@@ -1188,7 +1171,6 @@ panel_setup (PanelToplevel *toplevel)
 	pd = g_new0 (PanelData,1);
 	pd->menu = NULL;
 	pd->panel = GTK_WIDGET (toplevel);
-	pd->deactivate_idle = 0;
 
 	g_object_set_data (G_OBJECT (toplevel), "PanelData", pd);
 
@@ -1216,15 +1198,6 @@ panel_setup (PanelToplevel *toplevel)
 	g_signal_connect (toplevel, "destroy", G_CALLBACK (panel_destroy), pd);
 }
 
-GdkScreen *
-panel_screen_from_panel_widget (PanelWidget *panel)
-{
-	g_return_val_if_fail (PANEL_IS_WIDGET (panel), NULL);
-	g_return_val_if_fail (PANEL_IS_TOPLEVEL (panel->toplevel), NULL);
-
-	return gtk_window_get_screen (GTK_WINDOW (panel->toplevel));
-}
-
 static void
 panel_delete_without_query (PanelToplevel *toplevel)
 {
