@@ -214,24 +214,24 @@ GResource *action_button_get_resource (void)
 #ifdef G_HAS_CONSTRUCTORS
 
 #ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
-#pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(resource_constructor)
+#pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(action_buttonresource_constructor)
 #endif
-G_DEFINE_CONSTRUCTOR(resource_constructor)
+G_DEFINE_CONSTRUCTOR(action_buttonresource_constructor)
 #ifdef G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA
-#pragma G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(resource_destructor)
+#pragma G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(action_buttonresource_destructor)
 #endif
-G_DEFINE_DESTRUCTOR(resource_destructor)
+G_DEFINE_DESTRUCTOR(action_buttonresource_destructor)
 
 #else
 #warning "Constructor not supported on this compiler, linking in resources will not work"
 #endif
 
-static void resource_constructor (void)
+static void action_buttonresource_constructor (void)
 {
   g_static_resource_init (&static_resource);
 }
 
-static void resource_destructor (void)
+static void action_buttonresource_destructor (void)
 {
   g_static_resource_fini (&static_resource);
 }
