@@ -27,7 +27,7 @@ struct _ClockLocationPrivate {
 	GWeatherLocation *world;
 	GWeatherLocation *loc;
 
-	GWeatherTimezone *wtz;
+	GTimeZone        *tz;
 
         gdouble latitude;
         gdouble longitude;
@@ -55,13 +55,13 @@ static void clock_location_finalize (GObject *);
 static gboolean update_weather_info (gpointer user_data);
 static void setup_weather_updates (ClockLocation *loc);
 
-static GWeatherTimezone *
+static GTimeZone *
 get_gweather_timezone (ClockLocation *loc)
 {
-	GWeatherTimezone *tz;
+	GTimeZone *tz;
 	GWeatherLocation *gloc;
 
-	gloc = gweather_location_ref (loc->priv->loc);
+	gloc = g_object_ref (loc->priv->loc);
 	tz = gweather_location_get_timezone (gloc);
 
 	if (tz == NULL) {
@@ -72,34 +72,29 @@ get_gweather_timezone (ClockLocation *loc)
 		while (gweather_location_get_level (gloc) >= GWEATHER_LOCATION_CITY) {
 			tmp = gloc;
 
-#ifdef HAVE_GWEATHER_40
 			gloc = gweather_location_get_parent (gloc);
-#else
-			gloc = gweather_location_get_parent (gloc);
-			gloc = gweather_location_ref (gloc);
-#endif
 
-			gweather_location_unref (tmp);
+			g_object_unref (tmp);
 		}
 
 		tmp = gloc;
 		gloc = gweather_location_find_nearest_city (gloc,
 		                                            loc->priv->latitude,
 		                                            loc->priv->longitude);
-		gweather_location_unref (tmp);
+		g_object_unref (tmp);
 
 		if (gloc == NULL) {
 			g_warning ("Could not find the nearest city for location \"%s\"",
 			           gweather_location_get_name (loc->priv->loc));
-			return gweather_timezone_get_utc ();
+			return g_time_zone_new_utc ();
 		}
 
 		tz = gweather_location_get_timezone (gloc);
-		tz = gweather_timezone_ref (tz);
-		gweather_location_unref (gloc);
+		tz = g_time_zone_ref (tz);
+		g_object_unref (gloc);
 	} else {
-		tz = gweather_timezone_ref (tz);
-		gweather_location_unref (gloc);
+		tz = g_time_zone_ref (tz);
+		g_object_unref (gloc);
 	}
 
 	return tz;
@@ -121,7 +116,7 @@ clock_location_new (GnomeWallClock   *wall_clock,
         priv = this->priv;
 
 	priv->wall_clock = g_object_ref (wall_clock);
-	priv->world = gweather_location_ref (world);
+	priv->world = g_object_ref (world);
 	priv->loc = gweather_location_find_by_station_code (priv->world,
 							    metar_code);
 
@@ -138,7 +133,14 @@ clock_location_new (GnomeWallClock   *wall_clock,
 		gweather_location_get_coords (priv->loc, &priv->latitude, &priv->longitude);
 	}
 
-	priv->wtz = get_gweather_timezone (this);
+	priv->tz = get_gweather_timezone (this);
+
+	if (priv->tz == NULL) {
+		g_warning ("Failed to get timezone for - %s, falling back to UTC!",
+		           priv->name);
+
+		priv->tz = g_time_zone_new_utc ();
+	}
 
         setup_weather_updates (this);
 
@@ -219,10 +221,10 @@ clock_location_finalize (GObject *g_obj)
 
 	g_object_unref (priv->wall_clock);
 
-	gweather_location_unref (priv->world);
-	gweather_location_unref (priv->loc);
+	g_object_unref (priv->world);
+	g_object_unref (priv->loc);
 
-	gweather_timezone_unref (priv->wtz);
+	g_time_zone_unref (priv->tz);
 
 	if (priv->weather_timeout)
 		g_source_remove (priv->weather_timeout);
@@ -262,16 +264,34 @@ clock_location_get_city (ClockLocation *loc)
         return gweather_location_get_city_name (loc->priv->loc);
 }
 
-const gchar *
-clock_location_get_timezone (ClockLocation *loc)
+GTimeZone *
+clock_location_get_timezone (ClockLocation *self)
 {
-	return gweather_timezone_get_name (loc->priv->wtz);
+  return self->priv->tz;
 }
 
-const gchar *
-clock_location_get_tzname (ClockLocation *loc)
+const char *
+clock_location_get_timezone_identifier (ClockLocation *self)
 {
-	return gweather_timezone_get_tzid (loc->priv->wtz);
+  return g_time_zone_get_identifier (self->priv->tz);
+}
+
+const char *
+clock_location_get_timezone_abbreviation (ClockLocation *self)
+{
+  GDateTime *dt;
+  gint64 now;
+  int interval;
+
+  dt = g_date_time_new_now_local ();
+  now = g_date_time_to_unix (dt);
+  g_date_time_unref (dt);
+
+  interval = g_time_zone_find_interval (self->priv->tz,
+                                        G_TIME_TYPE_STANDARD,
+                                        now);
+
+  return g_time_zone_get_abbreviation (self->priv->tz, interval);
 }
 
 void
@@ -286,24 +306,7 @@ clock_location_get_coords (ClockLocation *loc,
 GDateTime *
 clock_location_localtime (ClockLocation *loc)
 {
-	const char *tzid;
-	GTimeZone *tz;
-	GDateTime *dt;
-
-	tzid = gweather_timezone_get_tzid (loc->priv->wtz);
-	tz = g_time_zone_new_identifier (tzid);
-
-	if (tz == NULL) {
-		g_warning ("Invalid timezone identifier - %s, falling back to UTC!",
-		           tzid);
-
-		tz = g_time_zone_new_utc ();
-	}
-
-	dt = g_date_time_new_now (tz);
-	g_time_zone_unref (tz);
-
-	return dt;
+  return g_date_time_new_now (loc->priv->tz);
 }
 
 gboolean
@@ -316,7 +319,7 @@ clock_location_is_current_timezone (ClockLocation *loc)
 	zone = g_time_zone_get_identifier (timezone);
 
 	if (zone)
-		return strcmp (zone, gweather_timezone_get_tzid (loc->priv->wtz)) == 0;
+		return strcmp (zone, g_time_zone_get_identifier (loc->priv->tz)) == 0;
 	else
 		return clock_location_get_offset (loc) == 0;
 }
@@ -348,7 +351,26 @@ clock_location_is_current (ClockLocation *loc)
 glong
 clock_location_get_offset (ClockLocation *loc)
 {
-	return gweather_timezone_get_offset (loc->priv->wtz);
+  GDateTime *datetime;
+  gint64 now;
+  GTimeZone *timezone;
+  int interval;
+  gint32 system_offset;
+  gint32 location_offset;
+
+  datetime = g_date_time_new_now_local ();
+  now = g_date_time_to_unix (datetime);
+  g_date_time_unref (datetime);
+
+  timezone = gnome_wall_clock_get_timezone (loc->priv->wall_clock);
+  interval = g_time_zone_find_interval (timezone, G_TIME_TYPE_STANDARD, now);
+  system_offset = g_time_zone_get_offset (timezone, interval);
+
+  timezone = loc->priv->tz;
+  interval = g_time_zone_find_interval (timezone, G_TIME_TYPE_STANDARD, now);
+  location_offset = g_time_zone_get_offset (timezone, interval);
+
+  return system_offset - location_offset;
 }
 
 typedef struct {
@@ -428,7 +450,7 @@ clock_location_make_current (ClockLocation *loc,
 	mcdata->data = data;
 	mcdata->destroy = destroy;
 
-	set_system_timezone_async (gweather_timezone_get_tzid (loc->priv->wtz),
+	set_system_timezone_async (g_time_zone_get_identifier (loc->priv->tz),
 	                           make_current_cb,
 	                           mcdata);
 }
@@ -501,10 +523,8 @@ static void
 setup_weather_updates (ClockLocation *loc)
 {
 	ClockLocationPrivate *priv;
-#ifdef HAVE_GWEATHER_40
 	const char *contact_info;
 	GWeatherProvider providers;
-#endif
 
 	priv = loc->priv;
 
@@ -517,7 +537,6 @@ setup_weather_updates (ClockLocation *loc)
 
 	priv->weather_info = gweather_info_new (priv->loc);
 
-#ifdef HAVE_GWEATHER_40
 	gweather_info_set_application_id (priv->weather_info, "org.gnome.gnome-panel");
 
 	contact_info = "https://gitlab.gnome.org/GNOME/gnome-panel/-/raw/master/gnome-panel.doap";
@@ -525,14 +544,11 @@ setup_weather_updates (ClockLocation *loc)
 
 	providers = GWEATHER_PROVIDER_METAR | GWEATHER_PROVIDER_IWIN;
 	gweather_info_set_enabled_providers (priv->weather_info, providers);
-#endif
 
 	g_signal_connect (priv->weather_info, "updated",
 			  G_CALLBACK (weather_info_updated), loc);
 
 	set_weather_update_timeout (loc);
 
-#ifdef HAVE_GWEATHER_40
 	gweather_info_update (priv->weather_info);
-#endif
 }
